@@ -14,8 +14,7 @@ api_key_file_path = os.environ.get(DASHSCOPE_API_KEY_FILE_PATH_ENV)
 # define api base url, ensure end /
 base_http_api_url = os.environ.get(
     'DASHSCOPE_HTTP_BASE_URL',
-    'https://dashscope-%s.aliyun-inc.com/api/%s' % (api_region, api_version))
+    'https://dashscope.aliyuncs.com/api/%s' % (api_version))
 base_websocket_api_url = os.environ.get(
     'DASHSCOPE_WEBSOCKET_BASE_URL',
-    'wss://dashscope-%s.aliyun-inc.com/api-ws/%s/inference' %
-    (api_region, api_version))
+    'wss://dashscope.aliyuncs.com/api-ws/%s/inference' % (api_version))
